@@ -245,7 +245,7 @@ use MIME::Decoder;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.503";
+$VERSION = "5.506";
 
 ### Boundary counter:
 my $BCount = 0;
@@ -570,7 +570,7 @@ sub build {
     $filename = undef if (defined($filename) and $filename eq '');
 
     ### Type-check sanity:
-    if ($type =~ m{^(multipart|message)/}) {
+    if ($type =~ m{^(multipart/|message/(rfc822|partial|external-body|delivery-status|disposition-notification|feedback-report)$)}i) {
 	($encoding =~ /^(|7bit|8bit|binary|-suggest)$/i)
 	    or croak "can't have encoding $encoding for message type $type!";
     }
@@ -1700,7 +1700,7 @@ sub dump_skeleton {
 I<Instance method, override.>
 Print the entity to the given OUTSTREAM, or to the currently-selected
 filehandle if none given.  OUTSTREAM can be a filehandle, or any object
-that reponds to a print() message.
+that responds to a print() message.
 
 The entity is output as a valid MIME stream!  This means that the
 header is always output first, and the body data (if any) will be
@@ -1779,7 +1779,7 @@ sub print {
 I<Instance method, override.>
 Print the body of the entity to the given OUTSTREAM, or to the
 currently-selected filehandle if none given.  OUTSTREAM can be a
-filehandle, or any object that reponds to a print() message.
+filehandle, or any object that responds to a print() message.
 
 The body is output for inclusion in a valid MIME stream; this means
 that the body data will be encoded if the header says that it should be.
@@ -2250,7 +2250,7 @@ L<MIME::Tools>, L<MIME::Head>, L<MIME::Body>, L<MIME::Decoder>, L<Mail::Internet
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
-David F. Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
+Dianne Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
 
 All rights reserved.  This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
